@@ -26,17 +26,17 @@
 #include <libkdegamesprivate/kgame/kplayer.h>
 #include <libkdegamesprivate/kgame/kgamepropertyhandler.h>
 
-#include <klistwidget.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kpushbutton.h>
+#include <QListWidget>
+#include <KLocalizedString>
+#include "kfourinline_debug.h"
+#include <qpushbutton.h>
 #include <KStandardGuiItem>
 
-#include <QTreeWidget>
-#include <QLayout>
 
+#include <QTreeWidget>
+#include <QGridLayout>
+#include <QTime>
 #include <QLabel>
-#include <QDateTime>
 #include <QVBoxLayout>
 #include <QFrame>
 #include <QHBoxLayout>
@@ -104,7 +104,7 @@ public:
 	QTreeWidgetItem* mGamePlayerCount;
 
 	QFrame* mPlayerPage;
-	KListWidget* mPlayerList;
+	QListWidget* mPlayerList;
 	QTreeWidget* mPlayerProperties;
 	QTreeWidgetItem* mPlayerAddress;
 	QTreeWidgetItem* mPlayerId;
@@ -121,18 +121,18 @@ public:
 
 	QFrame* mMessagePage;
 	QTreeWidget* mMessageList;
-	KListWidget* mHideIdList;
+	QListWidget* mHideIdList;
 };
 
 KGameDebugDialog::KGameDebugDialog(KGame* g, QWidget* parent, bool modal)
     : KPageDialog(parent),
       d( new KGameDebugDialogPrivate )
 {
- setCaption(i18n("KGame Debug Dialog"));
- setButtons(Close);
- setDefaultButton(Close);
+ setWindowTitle(i18n("KGame Debug Dialog"));
+ //QT5 setButtons(Close);
+ //QT5 setDefaultButton(Close);
  setModal(modal);
- showButtonSeparator(true);
+ //QT5 showButtonSeparator(true);
  setFaceType(KPageDialog::Tabbed);
 
  initGamePage();
@@ -152,8 +152,8 @@ void KGameDebugDialog::initGamePage()
  d->mGamePage = new QFrame();
  addPage(d->mGamePage,i18n("Debug &KGame"));
  QVBoxLayout* topLayout = new QVBoxLayout(d->mGamePage);
- topLayout->setMargin( marginHint() );
- topLayout->setSpacing( spacingHint() );
+ //QT5 topLayout->setMargin( marginHint() );
+ //QT5 topLayout->setSpacing( spacingHint() );
  QHBoxLayout* layout = new QHBoxLayout;
  topLayout->addLayout(layout);
 
@@ -173,7 +173,7 @@ void KGameDebugDialog::initGamePage()
  layout->addWidget(d->mGameProperties);
 
  QPushButton* b = new QPushButton(i18n("Update"), d->mGamePage);
- connect(b, SIGNAL(pressed()), this, SLOT(slotUpdateGameData()));
+ connect(b, &QPushButton::pressed, this, &KGameDebugDialog::slotUpdateGameData);
  topLayout->addWidget(b);
 
 // game data
@@ -195,8 +195,8 @@ void KGameDebugDialog::initPlayerPage()
  d->mPlayerPage = new QFrame();
  addPage(d->mPlayerPage,i18n("Debug &Players"));
  QVBoxLayout* topLayout = new QVBoxLayout(d->mPlayerPage);
- topLayout->setMargin( marginHint() );
- topLayout->setSpacing( spacingHint() );
+ //QT5 topLayout->setMargin( marginHint() );
+ //QT5 topLayout->setSpacing( spacingHint() );
  QHBoxLayout* layout = new QHBoxLayout;
  topLayout->addLayout(layout);
 
@@ -205,7 +205,7 @@ void KGameDebugDialog::initPlayerPage()
  layout->addLayout(listLayout);
  QLabel* listLabel = new QLabel(i18n("Available Players"), d->mPlayerPage);
  listLayout->addWidget(listLabel);
- d->mPlayerList = new KListWidget(d->mPlayerPage);
+ d->mPlayerList = new QListWidget(d->mPlayerPage);
  connect(d->mPlayerList, SIGNAL(executed(QListWidgetItem*)), this, SLOT(slotUpdatePlayerData(QListWidgetItem*)));
  listLayout->addWidget(d->mPlayerList);
  d->mPlayerList->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding));
@@ -225,7 +225,7 @@ void KGameDebugDialog::initPlayerPage()
  layout->addWidget(d->mPlayerProperties);
 
  QPushButton* b = new QPushButton(i18n("Update"), d->mPlayerPage);
- connect(b, SIGNAL(pressed()), this, SLOT(slotUpdatePlayerList()));
+ connect(b, &QPushButton::pressed, this, &KGameDebugDialog::slotUpdatePlayerList);
  topLayout->addWidget(b);
 
  d->mPlayerAddress = new QTreeWidgetItem(v, QStringList(i18n("Player Pointer")));
@@ -247,8 +247,8 @@ void KGameDebugDialog::initMessagePage()
  d->mMessagePage = new QFrame();
  addPage(d->mMessagePage,i18n("Debug &Messages"));
  QGridLayout* layout = new QGridLayout(d->mMessagePage);
- layout->setMargin(marginHint());
- layout->setSpacing(spacingHint());
+ //QT5 layout->setMargin(marginHint());
+ //QT5 layout->setSpacing(spacingHint());
  d->mMessageList = new QTreeWidget(d->mMessagePage);
  layout->addWidget(d->mMessageList, 0, 0, 10, 4);
 
@@ -260,20 +260,21 @@ void KGameDebugDialog::initMessagePage()
  d->mMessageList->setHeaderItem(mMessageListHeader);
 
  QPushButton* hide = new QPushButton(i18n("&>>"), d->mMessagePage);
- connect(hide, SIGNAL(pressed()), this, SLOT(slotHideId()));
+ connect(hide, &QPushButton::pressed, this, &KGameDebugDialog::slotHideId);
  layout->addWidget(hide, 4, 4);
 
  QPushButton* show = new QPushButton(i18n("&<<"), d->mMessagePage);
- connect(show, SIGNAL(pressed()), this, SLOT(slotShowId()));
+ connect(show, &QPushButton::pressed, this, &KGameDebugDialog::slotShowId);
  layout->addWidget(show, 6, 4);
 
  QLabel* l = new QLabel(i18n("Do not show IDs:"), d->mMessagePage);
  layout->addWidget(l, 0, 5, 1, 2);
- d->mHideIdList = new KListWidget(d->mMessagePage);
+ d->mHideIdList = new QListWidget(d->mMessagePage);
  layout->addWidget(d->mHideIdList, 1, 5, 8, 2);
 
- QPushButton* clear = new KPushButton(KStandardGuiItem::clear(), d->mMessagePage);
- connect(clear, SIGNAL(pressed()), this, SLOT(slotClearMessages()));
+ QPushButton* clear = new QPushButton(d->mMessagePage);
+ KGuiItem::assign(clear, KStandardGuiItem::clear());
+ connect(clear, &QPushButton::pressed, this, &KGameDebugDialog::slotClearMessages);
  layout->addWidget(clear, 10, 0, 1, 7);
  //TODO: "show all but..." and "show nothing but..."
 }
@@ -381,7 +382,7 @@ void KGameDebugDialog::slotUpdateGameData()
   QStringList items;
   items << handler->propertyName(it.value()->id()) << handler->propertyValue(it.value()) << policy;
 	new QTreeWidgetItem(d->mGameProperties,items);
-//	kDebug(11001) << ": checking for all game properties: found property name" << name;
+//	qCDebug(KFOURINLINE_LOG) << ": checking for all game properties: found property name" << name;
  }
 }
 
@@ -394,7 +395,7 @@ void KGameDebugDialog::slotUpdatePlayerData(QListWidgetItem* item)
  KPlayer* p = d->mGame->findPlayer(item->text().toInt());
 
  if (!p) {
-	kError(11001) << ": cannot find player";
+	qCCritical(KFOURINLINE_LOG) << ": cannot find player";
 	return;
  }
 
@@ -485,7 +486,7 @@ void KGameDebugDialog::slotUnsetKGame()
 void KGameDebugDialog::addPlayer(KPlayer* p)
 {
  if (!p) {
-	kError(11001) << "trying to add NULL player";
+	qCCritical(KFOURINLINE_LOG) << "trying to add NULL player";
 	return;
  }
 
@@ -575,4 +576,4 @@ bool KGameDebugDialog::showId(int msgid)
 }
 
 
-#include "kgamedebugdialog.moc"
+
